Package: rematch2
Title: Tidy Output from Regular Expression Matching
Version: 2.1.2
Authors@R: c(
    person("Gábor", "Csárdi", email = "csardi.gabor@gmail.com", role = c("aut", "cre")),
    person("Matthew", "Lincoln", email = "matthew.d.lincoln@gmail.com", role = c("ctb")))
Description: Wrappers on 'regexpr' and 'gregexpr' to return the match
    results in tidy data frames.
License: MIT + file LICENSE
LazyData: true
URL: https://github.com/r-lib/rematch2#readme
BugReports: https://github.com/r-lib/rematch2/issues
RoxygenNote: 7.1.0
Imports: tibble
Suggests: covr, testthat
Encoding: UTF-8
Author: Gábor Csárdi [aut, cre],
  Matthew Lincoln [ctb]
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Built: R 4.4.0; ; 2024-04-28 06:14:05 UTC; unix
