Package: rematch2
Title: Tidy Output from Regular Expression Matching
Version: 2.0.1
Author: Gábor Csárdi
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Description: Wrappers on 'regexpr' and 'gregexpr' to return the match
    results in tidy data frames.
License: MIT + file LICENSE
LazyData: true
URL: https://github.com/r-lib/rematch2#readme
BugReports: https://github.com/r-lib/rematch2/issues
RoxygenNote: 6.0.1
Imports: tibble
Suggests: covr, testthat
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2017-06-20 15:38:29 UTC; gaborcsardi
Repository: CRAN
Date/Publication: 2017-06-20 17:21:11 UTC
Built: R 3.5.1; ; 2018-09-09 05:57:22 UTC; windows
