# Generated by roxygen2: do not edit by hand

S3method("$",rematch_allrecords)
S3method("$",rematch_records)
export("$.rematch_allrecords")
export("$.rematch_records")
export(re_exec)
export(re_exec_all)
export(re_match)
export(re_match_all)
importFrom(tibble,tibble)
